@@ -17,7 +17,7 @@
  * Boston, MA 02111-1307, USA.
  */
 
-/* $Id: xmemory.c,v 1.1.1.1 2000/05/22 13:07:52 nmav Exp $ */
+/* $Id: xmemory.c,v 1.2 2001/01/23 11:51:19 nmav Exp $ */
 
 #ifndef LIBDEFS_H
 # define LIBDEFS_H
@@ -57,17 +57,8 @@ void *mxmalloc(size_t size)
 	if (x != NULL) {
 		LOCKMEM(x, size);
 		return x;
-	} else {
-		sleep(1);
-		x = malloc(size);
-		if (x != NULL) {
-			LOCKMEM(x, size);
-			return x;
-		} else {
-			fprintf(stderr, ("Cannot allocate memory\n"));
-			return NULL;
-		}
 	}
+	return NULL;
 }
 
 void *mxcalloc(size_t nmemb, size_t size)
@@ -78,17 +69,8 @@ void *mxcalloc(size_t nmemb, size_t size)
 	if (x != NULL) {
 		LOCKMEM(x, size);
 		return x;
-	} else {
-		sleep(1);
-		x = calloc(nmemb, size);
-		if (x != NULL) {
-			LOCKMEM(x, size);
-			return x;
-		} else {
-			fprintf(stderr, ("Cannot allocate memory\n"));
-			return NULL;
-		}
 	}
+	return NULL;
 }
 
 void *mxrealloc(void *ptr, size_t size)
@@ -99,17 +81,8 @@ void *mxrealloc(void *ptr, size_t size)
 	if (x != NULL) {
 		LOCKMEM(x, size);
 		return x;
-	} else {
-		sleep(1);
-		x = realloc(ptr, size);
-		if (x != NULL) {
-			LOCKMEM(x, size);
-			return x;
-		} else {
-			fprintf(stderr, ("Cannot allocate memory\n"));
-			return NULL;
-		}
 	}
+	return NULL;
 }
 
 
