@@ -7,24 +7,26 @@
  * All modifications are placed under the license of libmcrypt.
  */
 
-/* $Id: blowfish-compat.c,v 1.3 2001/01/23 11:51:19 nmav Exp $ */
+/* $Id: blowfish.c,v 1.6 2000/11/08 23:25:36 nmav Exp $ */
 
 #include "../../lib/libdefs.h"
 #include "../../lib/mcrypt_modules.h"
 #include "blowfish.h"
 
+#define WORDS_BIGENDIAN
+
 #ifdef USE_LTDL
-#define _mcrypt_set_key blowfish_LTX__mcrypt_set_key
-#define _mcrypt_encrypt blowfish_LTX__mcrypt_encrypt
-#define _mcrypt_decrypt blowfish_LTX__mcrypt_decrypt
-#define _mcrypt_get_size blowfish_LTX__mcrypt_get_size
-#define _mcrypt_get_block_size blowfish_LTX__mcrypt_get_block_size
-#define _is_block_algorithm blowfish_LTX__is_block_algorithm
-#define _mcrypt_get_key_size blowfish_LTX__mcrypt_get_key_size
-#define _mcrypt_get_supported_key_sizes blowfish_LTX__mcrypt_get_supported_key_sizes
-#define _mcrypt_get_algorithms_name blowfish_LTX__mcrypt_get_algorithms_name
-#define _mcrypt_self_test blowfish_LTX__mcrypt_self_test
-#define _mcrypt_algorithm_version blowfish_LTX__mcrypt_algorithm_version
+#define _mcrypt_set_key blowfish_compat_LTX__mcrypt_set_key
+#define _mcrypt_encrypt blowfish_compat_LTX__mcrypt_encrypt
+#define _mcrypt_decrypt blowfish_compat_LTX__mcrypt_decrypt
+#define _mcrypt_get_size blowfish_compat_LTX__mcrypt_get_size
+#define _mcrypt_get_block_size blowfish_compat_LTX__mcrypt_get_block_size
+#define _is_block_algorithm blowfish_compat_LTX__is_block_algorithm
+#define _mcrypt_get_key_size blowfish_compat_LTX__mcrypt_get_key_size
+#define _mcrypt_get_supported_key_sizes blowfish_compat_LTX__mcrypt_get_supported_key_sizes
+#define _mcrypt_get_algorithms_name blowfish_compat_LTX__mcrypt_get_algorithms_name
+#define _mcrypt_self_test blowfish_compat_LTX__mcrypt_self_test
+#define _mcrypt_algorithm_version blowfish_compat_LTX__mcrypt_algorithm_version
 #endif
 
 /*
@@ -38,7 +40,11 @@ typedef struct {
 #define BF_N         16
 #define KEYBYTES   8
 
-#define F(bc, x) ( ((bc->S[0][(x >> 24) & 0xff] + bc->S[1][(x >> 16) & 0xff]) ^ bc->S[2][(x >>  8) & 0xff]) + bc->S[3][x & 0xff] )
+static word32 F(blf_ctx * bc, word32 x)
+{
+	return ((bc->S[0][(x >> 24) & 0xff] + bc->S[1][(x >> 16) & 0xff]) ^ bc->S[2][(x >>  8) & 0xff]) + bc->S[3][(x      ) & 0xff];
+
+}
 
 /* x should be a 64 bit integer */
 WIN32DLL_DEFINE
@@ -152,7 +158,7 @@ void _mcrypt_decrypt(blf_ctx * c, word32 * x)
 }
 
 
-static short initialize_blowfish(blf_ctx * c, byte key[], short keybytes)
+static short initialize_blowfish(blf_ctx * c, unsigned char key[], short keybytes)
 {
 	short i, j;
 	word32 data, datarl[2];
@@ -568,10 +574,9 @@ static short initialize_blowfish(blf_ctx * c, byte key[], short keybytes)
 }
 
 WIN32DLL_DEFINE
-int _mcrypt_set_key(blf_ctx * c, char *k, int len)
+void _mcrypt_set_key(blf_ctx * c, char *k, int len)
 {
 	initialize_blowfish(c, k, len);
-	return 0;
 }
 
 WIN32DLL_DEFINE
@@ -590,7 +595,7 @@ int* _mcrypt_get_supported_key_sizes(int *len) {
 WIN32DLL_DEFINE
 char * _mcrypt_get_algorithms_name() { char*x; x=malloc(10); strcpy(x, "Blowfish"); return x;}
 
-#define CIPHER "de8e9a3a9cd44280"
+#define CIPHER "c8c033bc57874d74"
 
 WIN32DLL_DEFINE
 int _mcrypt_self_test() {
