@@ -7,24 +7,24 @@
  * All modifications are placed under the license of libmcrypt.
  */
 
-/* $Id: blowfish.c,v 1.13 2001/01/23 11:51:19 nmav Exp $ */
+/* $Id: blowfish.c,v 1.14 2001/03/11 20:30:28 nmav Exp $ */
 
 #include "../../lib/libdefs.h"
 #include "../../lib/mcrypt_modules.h"
 #include "blowfish.h"
 
 #ifdef USE_LTDL
-#define _mcrypt_set_key blowfish_compat_LTX__mcrypt_set_key
-#define _mcrypt_encrypt blowfish_compat_LTX__mcrypt_encrypt
-#define _mcrypt_decrypt blowfish_compat_LTX__mcrypt_decrypt
-#define _mcrypt_get_size blowfish_compat_LTX__mcrypt_get_size
-#define _mcrypt_get_block_size blowfish_compat_LTX__mcrypt_get_block_size
-#define _is_block_algorithm blowfish_compat_LTX__is_block_algorithm
-#define _mcrypt_get_key_size blowfish_compat_LTX__mcrypt_get_key_size
-#define _mcrypt_get_supported_key_sizes blowfish_compat_LTX__mcrypt_get_supported_key_sizes
-#define _mcrypt_get_algorithms_name blowfish_compat_LTX__mcrypt_get_algorithms_name
-#define _mcrypt_self_test blowfish_compat_LTX__mcrypt_self_test
-#define _mcrypt_algorithm_version blowfish_compat_LTX__mcrypt_algorithm_version
+#define _mcrypt_set_key blowfish_LTX__mcrypt_set_key
+#define _mcrypt_encrypt blowfish_LTX__mcrypt_encrypt
+#define _mcrypt_decrypt blowfish_LTX__mcrypt_decrypt
+#define _mcrypt_get_size blowfish_LTX__mcrypt_get_size
+#define _mcrypt_get_block_size blowfish_LTX__mcrypt_get_block_size
+#define _is_block_algorithm blowfish_LTX__is_block_algorithm
+#define _mcrypt_get_key_size blowfish_LTX__mcrypt_get_key_size
+#define _mcrypt_get_supported_key_sizes blowfish_LTX__mcrypt_get_supported_key_sizes
+#define _mcrypt_get_algorithms_name blowfish_LTX__mcrypt_get_algorithms_name
+#define _mcrypt_self_test blowfish_LTX__mcrypt_self_test
+#define _mcrypt_algorithm_version blowfish_LTX__mcrypt_algorithm_version
 #endif
 
 #define MAXKEYBYTES 56		/* 448 bits */
