@@ -1,5 +1,5 @@
 /*
- * $Id: cast-128.c,v 1.3 2000/10/12 21:06:31 nmav Exp $
+ * $Id: cast-128.c,v 1.5 2001/01/23 11:51:19 nmav Exp $
  *
  *	CAST-128 in C
  *	Written by Steve Reid <sreid@sea-to-sky.net>
@@ -13,7 +13,7 @@
  * All modifications are placed under the license of libmcrypt.
  */
 
-/* $Id: cast-128.c,v 1.3 2000/10/12 21:06:31 nmav Exp $ */
+/* $Id: cast-128.c,v 1.5 2001/01/23 11:51:19 nmav Exp $ */
 
 #include "../../lib/libdefs.h"
 #include "../../lib/mcrypt_modules.h"
@@ -33,7 +33,7 @@
 #define _mcrypt_algorithm_version cast_128_LTX__mcrypt_algorithm_version
 #endif
 
-#define u8 word8
+#define u8 byte
 #define u32 word32
 
 #include "cast-128_sboxes.h"
@@ -157,7 +157,7 @@ void _mcrypt_decrypt(CAST_KEY *key, u8 * block)
 /***** Key Schedual *****/
 
 WIN32DLL_DEFINE
-void _mcrypt_set_key(CAST_KEY *key, u8 * rawkey,
+int _mcrypt_set_key(CAST_KEY *key, u8 * rawkey,
 			 unsigned keybytes)
 {
 	u32 t[4], z[4], x[4];
@@ -298,6 +298,7 @@ void _mcrypt_set_key(CAST_KEY *key, u8 * rawkey,
 	for (i = 0; i < 4; i++) {
 		t[i] = x[i] = z[i] = 0;
 	}
+return 0;
 }
 
 /* Made in Canada */
