@@ -13,7 +13,7 @@
  * All modifications are placed under the license of libmcrypt.
  */
 
-/* $Id: enigma.c,v 1.3 2000/10/12 21:06:31 nmav Exp $ */
+/* $Id: enigma.c,v 1.4 2001/01/22 22:13:19 nmav Exp $ */
 
 #include "../../lib/libdefs.h"
 #include "../../lib/mcrypt_modules.h"
@@ -40,7 +40,7 @@
  */
 
 WIN32DLL_DEFINE
-void _mcrypt_set_key(CRYPT_KEY *ckey, char* password, int plen, void* u1, int u2)
+int _mcrypt_set_key(CRYPT_KEY *ckey, char* password, int plen, void* u1, int u2)
 {
 	int ic, i, k, temp;
 	unsigned random;
@@ -84,7 +84,7 @@ void _mcrypt_set_key(CRYPT_KEY *ckey, char* password, int plen, void* u1, int u2
 	for (i = 0; i < ROTORSZ; i++)
 		ckey->t2[ckey->t1[i] & MASK] = i;
 
-	return;
+	return 0;
 }
 
 
